pygeodesy.namedTuples.Ellipse5Tuple

Package pygeodesy :: Module namedTuples :: Class Ellipse5Tuple |
[frames] | no frames]

# Class Ellipse5Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Ellipse5Tuple

5-Tuple `(a, b, height, lat, beta)` with semi-axes `a` and `b` of a parallel ellipse of latitude at (geodetic) latitude `lat` and parametric (or reduced) auxiliary latitude `beta` of a triaxial ellipsoid.

The `height` is the (signed) distance between the parallel and the triaxial's equatorial plane. At near-polar `lat`s, `a` and `b` are `0`, the `height` is the triaxial semi-axis `c` (signed) and `beta` equals `lat`. The latter are in `degrees90`, always.

See Also: Class Circle4Tuple.

Instance Methods
toTriaxial(self, **Triaxial_and_kwds) Return a Triaxial_ from this tuple's semi-axes `abc3ordered`. |
toTriaxial_(self, **Triaxial_and_kwds) Return a Triaxial_ from this tuple's semi-axes `abc3`. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
| abc3 Get the semi-axes as 3-tuple `(a, b, c)`, non-negative.
| abc3ordered Get the semi-axes as 3-tuple `(a, b, c)`, non-negative, ordered.
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toTriaxial (self, **Triaxial_and_kwds) |
Return a Triaxial_ from this tuple's semi-axes `abc3ordered`. Arguments: `Triaxial_and_kwds` - Optional `Triaxial=Triaxial` class and additional `Triaxial` keyword arguments.

### toTriaxial_ (self, **Triaxial_and_kwds) |
Return a Triaxial_ from this tuple's semi-axes `abc3`. Arguments: `Triaxial_and_kwds` - Optional `Triaxial=Triaxial_` class and additional `Triaxial_` keyword arguments.

Property Details

### abc3 Get the semi-axes as 3-tuple `(a, b, c)`, non-negative. Get method: abc3(self) - Get the semi-axes as 3-tuple `(a, b, c)`, non-negative. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### abc3ordered Get the semi-axes as 3-tuple `(a, b, c)`, non-negative, ordered. Get method: abc3ordered(self) - Get the semi-axes as 3-tuple `(a, b, c)`, non-negative, ordered. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.